@@ -33,7 +33,10 @@ def import_solution_from_repo(solution_name,version) :
     destination = '/files'
     run(['vctl','vrep','user','import-solution',solution_name,version,destination,])
 
-def export_solution_to_repo(source,solution_name,version) :
-    cmd = ['vctl','vrep','user','export-solution',solution_name,version,source]
+def export_solution_to_repo(source,solution_name,version,description) :
+    if description :
+        cmd = ['vctl','vrep','user','export-solution',solution_name,version,source,'-s',description]
+    else :
+        cmd = ['vctl','vrep','user','export-solution',solution_name,version,source]
     logging.info(f'Export vrep  \'{source}\'  to solution: {solution_name}-{version} ( ({" ".join(cmd)}))')
     run(cmd)
\ No newline at end of file
